# Prelude CLI

Interact with the full range of features in Build or Detect, organized by:

- IAM: manage your account 
- Build: write and maintain your collection of security tests
- Detect: schedule security tests for your endpoints

## Quick start
```bash
pip install prelude-cli
prelude --help
```

## Documentation

https://docs.preludesecurity.com/docs/prelude-cli
